[PATCH] rm: only refresh entries that we may touch
- From
Nguyễn Thái Ngọc Duy <pclouds@gmail.com>
- Date
- Jan 17, 2010, 08:43 UTC
- Message-ID
- <1263717793-24009-1-git-send-email-pclouds@gmail.com>
- In-Reply-To
- <1263481341-28401-1-git-send-email-pclouds@gmail.com>
This gets rid of the whole tree cache refresh. Instead only path that we touch will get refreshed. We may still lstat() more than needed, but it'd be better playing safe.
This potentially reduces a large number of lstat() on big trees. Take gentoo-x86 tree for example, which has roughly 80k files:
Unmodified Git:
$ time git rm --cached skel.ebuild rm 'skel.ebuild'
real 0m1.441s user 0m0.821s sys 0m0.531s
Modified Git:
$ time ~/w/git/git rm --cached skel.ebuild rm 'skel.ebuild'
real 0m0.941s user 0m0.828s sys 0m0.091s
Signed-off-by: Nguyễn Thái Ngọc Duy <pclouds@gmail.com> --- In the previous attempt, refresh_cache_entry() returns a new cache_entry. It does not modify the_index, so tests failed.
builtin-rm.c | 3 ++- 1 files changed, 2 insertions(+), 1 deletions(-)
diff --git a/builtin-rm.c b/builtin-rm.c index 57975db..f3772c8 100644 --- a/builtin-rm.c +++ b/builtin-rm.c @@ -169,9 +169,10 @@ int cmd_rm(int argc, const char **argv, const char *prefix) if (read_cache() < 0) die("index file corrupt"); - refresh_cache(REFRESH_QUIET); pathspec = get_pathspec(prefix, argv); + refresh_index(&the_index, REFRESH_QUIET, pathspec, NULL, NULL); + seen = NULL; for (i = 0; pathspec[i] ; i++) /* nothing */;
-- 1.6.6.181.g5ee6